\name{taillard.test}
\alias{taillard.test}
\title{Taillard Statistical Test to Compare Proportions}
\description{
    Performs Taillard Test to Compare Proportions given a 2x2
    contingency matrix
}
\usage{
taillard.test(x, alternative = "two.sided")
}
\arguments{
    \item{x}{a two-dimensional contingency table in matrix form}
    \item{alternative}{indicates the alternative hypothesis and must be
    one of \code{"two.sided"} or \code{"one.sided"}. You can specify just the
    initial letter.}
}
\value{
    A list with class \code{"htest"} containing the following components :
    \item{p.value}{the p-value of the test.}
    \item{alternative}{a character string describing the alternative
    hypothesis.}
    \item{method}{the character string
        \code{"Taillard Test to Compare Proportions"}.}
    \item{data.name}{a character string giving the names of the data.}
}
\details{
    \code{x} is a two-dimensional contingency table in matrix form,
    and hence its entries should be nonnegative integers.
}
\references{
    E. D. Taillard, Ph. Waelti, J. Zuber (2006).
    \emph{Few statistical tests for proportions comparison}.
    Technical Report, MiS-TIC, HEIG-Vd.
}
\seealso{
    \code{\link{fisher.test}}
    \code{\link{mcnemar.test}}
}
\examples{
VrpSolving <-
matrix(c(9, 2, 2, 4),
    nr = 2,
    dimnames =
    list(c("Sample 1", "Sample 2"),
         c("# success", "# failure")))

taillard.test(VrpSolving, alternative="two.sided")

## The p-value (significance level) associated with null hypothesis is
## 0.02496. Confidence level of alternate hypothesis (Sample 1 has a
## success rate different to Sample 2) : 0.97504
}
\keyword{htest}
